@@ -35,7 +35,8 @@ use EBox::Exceptions::MissingArgument;
 use EBox::Gettext;
 use EBox::Config;
 use English qw(-no_match_vars);
-use File::Basename();
+use File::Basename;
+use POSIX ('setsid');
 
 # Constants
 use constant RESTRICTED_RESOURCES_KEY    => 'restricted_resources';
@@ -64,6 +65,27 @@ sub initd
 	return '/usr/share/ebox/ebox-apache2ctl';
 }
 
+# Method: cleanupForExec
+#
+#	It does the job to prepare a forked apache process to do an exec.
+#	We should use spawn_proc_prog() from mod_perl but we experience
+#	some issues.
+#
+#
+sub cleanupForExec
+{
+    POSIX::setsid();
+
+	opendir(my $dir, "/proc/$$/fd");
+	while (defined(my $fd = readdir($dir))) {
+		next unless ($fd =~ /^\d+$/);
+		eval('POSIX::close($fd)');
+	}
+	open(STDOUT, '> /dev/null');
+	open(STDERR, '> /dev/null');
+	open(STDIN, '/dev/null');
+}
+
 # restarting apache from inside apache could be problematic, so we fork() and
 # detach the child from the process group.
 sub _daemon # (action) 
@@ -82,21 +104,22 @@ sub _daemon # (action)
 		if ($pid) { 
 			return; # parent returns inmediately
 		}
-
-		POSIX::setsid();
-		close(STDOUT);
-		close(STDERR);
-		open(STDOUT, "> /dev/null");
-		open(STDERR, "> /dev/null");
-		sleep(5);
-	}
+		cleanupForExec();
+	} 
 
 	if ($action eq 'stop') {
 		EBox::Sudo::root('/usr/share/ebox/ebox-apache2ctl stop');
 	} elsif ($action eq 'start') {
 		EBox::Sudo::root('/usr/share/ebox/ebox-apache2ctl start');
 	} elsif ($action eq 'restart') {
-		exec(EBox::Config::pkgdata . 'ebox-apache-restart');
+		my $restartCmd = EBox::Config::pkgdata . 'ebox-apache-restart';
+		if ($fork) {
+			exec($restartCmd);
+		}
+		else {
+			EBox::Sudo::root($restartCmd);
+		}
+
 	}
 
 	if ($fork) {
@@ -148,6 +171,7 @@ sub _writeHttpdConfFile
 	push @confFileParams, ( user => EBox::Config::user());
 	push @confFileParams, ( group => EBox::Config::group());
 	push @confFileParams, ( serverroot => $self->serverroot());
+	push @confFileParams, ( tmpdir => EBox::Config::tmp());
         push @confFileParams, ( restrictedResources => $self->_restrictedResources() );
 
         my $debugMode =  EBox::Config::configkey('debug') eq 'yes';
