@@ -159,8 +159,6 @@ sub authen_cred  # (request, password)
 {
     my ($self, $r, $passwd) = @_;
 
-    my $soapSession = $self->_activeSOAPSession();
-
     # If there's a SOAP session opened, give it priority to the
     # Web interface session
     if ( $self->_activeSOAPSession() ){
@@ -176,8 +174,12 @@ sub authen_cred  # (request, password)
 	return;
     }
 
+    my $rndStr;
+    for my $i (1..64) {
+        $rndStr .= rand (2**32);
+    }
     my $md5 = Digest::MD5->new;
-    $md5->add(time() . rand((2**50)));
+    $md5->add($rndStr);
     my $sid = $md5->hexdigest;
     _savesession($sid);
 
@@ -190,7 +192,7 @@ sub authen_cred  # (request, password)
 
 # Method: authen_ses_key
 #
-#   	Overriden method from <Apache22::AuthCookie>.
+#   	Overriden method from <Apache2::AuthCookie>.
 #
 sub authen_ses_key  # (request, session_key)
 {
