@@ -72,15 +72,17 @@ sub _makeBackup # (description, bug?)
 	my $confdir = EBox::Config::conf;
 	my $tempdir = tempdir("$confdir/backup.XXXXXX") or
 		throw EBox::Exceptions::Internal("Could not create tempdir.");
+	EBox::Sudo::command("chmod 0700 $tempdir");
+
 	my $auxDir = "$tempdir/aux";
 	my $archiveContentsDirRelative = "eboxbackup";
 	my $archiveContentsDir = "$tempdir/$archiveContentsDirRelative";
 	my $backupArchive = "$confdir/eboxbackup.tar";
 	
 	try {
-	  mkdir($auxDir) or
+	  mkdir($auxDir, 0700) or
 	    throw EBox::Exceptions::Internal("Could not create auxiliar tempdir.");
-	  mkdir($archiveContentsDir) or
+	  mkdir($archiveContentsDir, 0700) or
 	    throw EBox::Exceptions::Internal("Could not create archive tempdir.");
 
 	  $self->_dumpModulesBackupData($auxDir, %options);
@@ -128,15 +130,12 @@ sub _dumpModulesBackupData
 
   my $progress   = $options{progress};
 
-  my $global = EBox::Global->getInstance();
-  my @names = @{$global->modNames};
-  foreach my $modName (@names) {
+  my @modules = @{ $self->_modInstancesForBackup() };
+  foreach my $mod (@modules) {
+    my $modName = $mod->name();
     # XXX temporally skipping logs
     next if $modName eq 'logs';
 
-    my $mod = $global->modInstance($modName);
-
-
     if ($progress) {
       # update progress object
       $progress->notifyTick();
@@ -157,11 +156,52 @@ sub _dumpModulesBackupData
 
 }
 
+sub _modInstancesForBackup
+{
+  my ($self) = @_;
+
+  my @mods = @{ $self->_configuredModInstances };
+
+  return \@mods;
+}
+
+
+sub _configuredModInstances
+{
+  my ($self) = @_;
+
+  my $global = EBox::Global->getInstance();
+
+  my @modules =  @{ $global->modInstances() };
+
+
+  my @configuredModules;
+  foreach my $mod (@modules) {
+    if ($mod->can('configured')) {
+      if ($mod->configured()) {
+	push @configuredModules, $mod;
+      }
+    }
+    else {
+      push @configuredModules, $mod;
+    }
+  }
+  # leave aside not configured modules
+#   @modules = grep {
+# #    (not $_->isa('EBox::ServiceModule::ServiceInterface') or
+# #    ($_->configured())) 
+#     $_->configured()
+#   } @modules;
+
+  return \@configuredModules;
+}
+
+
 sub  _createFilesArchive
 {
   my ($self, $auxDir, $filesArchive) = @_;
 
-  if (`tar czf $filesArchive -C $auxDir .`) {
+  if (`umask 0077; tar czf $filesArchive -C $auxDir .`) {
     throw EBox::Exceptions::Internal("Could not create archive.");
   }
   `rm -rf $auxDir`;
@@ -234,8 +274,8 @@ sub  _createModulesListFile
 {
   my ($self, $archiveContentsDir) = @_;
 
-  my $global = EBox::Global->getInstance();
-  my @modNames = @{ $global->modNames() };
+  my @mods     = @{ $self->_modInstancesForBackup() };
+  my @modNames = map { $_->name  } @mods;
 
   my $file = "$archiveContentsDir/modules";
   write_file($file, "@modNames");
@@ -255,7 +295,7 @@ sub  _createBackupArchive
   my $cmd;
   my @output;
 
-  $cmd = "tar cf $backupArchive -C $tempdir $archiveContentsDirRelative  --exclude $filesArchive 2>&1";
+  $cmd = "umask 0077; tar cf $backupArchive -C $tempdir $archiveContentsDirRelative  --exclude $filesArchive 2>&1";
   @output = `$cmd`;
   if ($? != 0) {
     EBox::error("Failed command: $cmd. Output: @output");
@@ -401,6 +441,7 @@ sub _unpackArchive
 
   my $tempDir = tempdir(EBox::Config::tmp . "/backup.XXXXXX") or
     throw EBox::Exceptions::Internal("Could not create tempdir.");
+  EBox::Sudo::command("chmod 0700 $tempDir");
 
   my $filesWithPath =  @files > 0 ?
     join ' ', map { 'eboxbackup/' . $_  } @files : '';
@@ -521,7 +562,7 @@ sub _ensureBackupdirExistence
   my $backupdir = backupDir();
 
   unless (-d $backupdir) {
-    mkdir($backupdir) or throw EBox::Exceptions::Internal
+    mkdir($backupdir, 0700) or throw EBox::Exceptions::Internal
       ("Could not create backupdir.");
   }
 
@@ -1058,7 +1099,7 @@ sub _revokeRestore
 sub _migratePackage
 {
 	my ($self, $package) = @_;
-	my $migrationdir = EBox::Config::lib() . "/$package/migration";
+	my $migrationdir = EBox::Config::share() . "/$package/migration";
 	
 	if (-d $migrationdir) {
 		my $migration = EBox::Config::pkgdata() . '/ebox-migrate';
@@ -1078,9 +1119,8 @@ sub _modInstancesForRestore
 
   my $anyModuleInBackup = any( @{ $self->_modulesInBackup($archive) } );
 
-  my $global = EBox::Global->getInstance();
 
-  my @modules =  @{ $global->modInstances() };
+  my @modules =  @{ $self->_configuredModInstances };
 
 
   # if we have a module list we check it and only keep those modules
