@@ -21,7 +21,7 @@ use warnings;
 use base qw(EBox::GConfModule Apache::Singleton::Process);
 
 use EBox;
-use EBox::Validate qw( :all );
+use EBox::Exceptions::Command;
 use EBox::Exceptions::InvalidData;
 use EBox::Exceptions::DataNotFound;
 use EBox::Exceptions::Internal;
@@ -29,21 +29,25 @@ use EBox::Exceptions::DataExists;
 use Error qw(:try);
 use EBox::Config;
 use EBox::Gettext;
+use EBox::ProgressIndicator;
+use EBox::ProgressIndicator::Dummy;
+use EBox::Sudo;
+use EBox::Validate qw( :all );
+use File::Basename;
 use Log::Log4perl;
 use POSIX qw(setuid setgid setlocale LC_ALL);
 
 use Digest::MD5;
 
+# Constants
+use constant {
+    PRESAVE_SUBDIR  => EBox::Config::etc() . 'pre-save',
+    POSTSAVE_SUBDIR => EBox::Config::etc() . 'post-save',
+};
+
+
 #redefine inherited method to create own constructor
 #for Singleton pattern
-#sub _new_instance 
-#{
-	#my $class = shift;
-	#my $self  = bless { }, $class;
-	#$self->{'global'} = _create EBox::Global;
-	#return $self;
-#}
-
 sub _new_instance 
 {
 	my $class = shift;
@@ -218,6 +222,18 @@ sub unsaved
 	return undef;
 }
 
+
+sub prepareRevokeAllModules
+{
+    my ($self) = @_;
+
+    my $totalTicks = grep {
+	$self->modIsChanged($_);
+    }  @{$self->modNames};
+
+    return $self->_prepareActionScript('revokeAllModules', $totalTicks);
+}
+
 #
 # Method: revokeAllModules 
 #
@@ -225,12 +241,22 @@ sub unsaved
 #
 sub revokeAllModules
 {
-	my $self = shift;
+	my ($self, %options) = @_;
+
+	my $progress = $options{progress};
+	if (not $progress) {
+	    $progress = EBox::ProgressIndicator::Dummy->create();
+	}
+
 	my @names = @{$self->modNames};
 	my $failed = "";
 
 	foreach my $name (@names) {
 		$self->modIsChanged($name) or next;
+
+		$progress->setMessage($name);
+		$progress->notifyTick();
+
 		my $mod = $self->modInstance($name);
 		try {
 			$mod->revokeConfig;
@@ -238,11 +264,16 @@ sub revokeAllModules
 			$failed .= "$name ";
 		};
 	}
+
 	if ($failed eq "") {
-		return;
+	    $progress->setAsFinished();   
+	    return;
 	}
-	throw EBox::Exceptions::Internal("The following modules failed while ".
-		"revoking their changes, their state is unknown: $failed");
+
+	my $errorText = "The following modules failed while ".
+		"revoking their changes, their state is unknown: $failed";
+	$progress->setAsFinished(1, $errorText);  
+	throw EBox::Exceptions::Internal($errorText);
 }
 
 sub modifiedModules
@@ -272,18 +303,56 @@ sub modifiedModules
     return \@mods;
 }
 
+
+
+sub prepareSaveAllModules
+{
+    my ($self) = @_;
+
+    my $totalTicks = scalar @{$self->modifiedModules()}
+      + $self->_nScripts(PRESAVE_SUBDIR, POSTSAVE_SUBDIR);
+
+    return $self->_prepareActionScript('saveAllModules', $totalTicks);
+}
+
+
+sub _prepareActionScript
+{
+    my ($self, $action, $totalTicks) = @_;
+
+     my $script =   EBox::Config::pkgdata() . 'ebox-global-action';
+    $script .= " --action $action";
+
+
+    my $progressIndicator =  EBox::ProgressIndicator->create(
+			     executable => $script,
+			     totalTicks => $totalTicks,
+						    );
+
+    $progressIndicator->runExecutable();
+
+    return $progressIndicator;
+
+}
+
 # Method: saveAllModules
 #
 #      Save changes in all modules 		
 #
 sub saveAllModules
 {
-	my $self = shift;
+	my ($self, %options) = @_;
 
 	my $log = EBox::logger();
 
 	my $failed = "";
-	
+
+	my $progress = $options{progress};
+	if (not $progress) {
+	    $progress = EBox::ProgressIndicator::Dummy->create();
+	}
+
+        $self->_runExecFromDir(PRESAVE_SUBDIR, $progress);
 
 	my @mods = @{$self->modifiedModules()};
 	my $msg = "Saving config and restarting services: @mods";
@@ -296,11 +365,16 @@ sub saveAllModules
 			$apache = 1;
 			next;
 		}
+
+		$progress->setMessage(__x("Saving {modName} module",
+                                          modName => $name));
+		$progress->notifyTick();
+
 		my $mod = $self->modInstance($name);
 		my $class = 'EBox::ServiceModule::ServiceInterface';
 		if ($mod->isa($class) and not $mod->configured()) {
 			$mod->_saveConfig();
-            $self->modRestarted($name);
+			$self->modRestarted($name);
 			next;
 		}
 
@@ -313,6 +387,10 @@ sub saveAllModules
 
 	# FIXME - tell the CGI to inform the user that apache is restarting
 	if ($apache) {
+		$progress->setMessage(__x("Saving {modName} module",
+                                          modName => 'apache'));
+		$progress->notifyTick();
+
 		my $mod = $self->modInstance('apache');
 		try {
 			$mod->save();
@@ -321,12 +399,17 @@ sub saveAllModules
 		};
 
 	}
-	
 	if ($failed eq "") {
-		return;
+            $self->_runExecFromDir(POSTSAVE_SUBDIR, $progress);
+	    $progress->setAsFinished();
+            return;
 	}
-	throw EBox::Exceptions::Internal("The following modules failed while ".
-		"saving their changes, their state is unknown: $failed");
+
+	my $errorText = "The following modules failed while ".
+		"saving their changes, their state is unknown: $failed";
+
+	$progress->setAsFinished(1, $errorText);   
+	throw EBox::Exceptions::Internal($errorText);
 }
 
 #
@@ -489,72 +572,78 @@ sub modInstancesOfType # (classname)
 # 
 # Method: modInstance
 #
-# 	Build an instance of a module. Can be called as a class method or as an
-# 	object method.
+#       Build an instance of a module. Can be called as a class method or as an
+#       object method.
 #
 #   Parameters:
 #
-#   	module - module name
+#       module - module name
 #
 # Returns:
 #
-#   	If everything goes ok:
+#       If everything goes ok:
 #
-#   	<EBox::Module> - An instance of the requested module
+#       <EBox::Module> - An instance of the requested module
 #
-#   	Otherwise
+#       Otherwise
 #
-#   	undef
+#       undef
 sub modInstance # (module)
 {
-	my $self = shift;
-	my $name = shift;
-	if (!$self) {
-		throw EBox::Exceptions::Internal("Incorrect call to ".
-		"EBox::Global modInstance(), maybe it was called as an static".
-		" function instead of an instance method?");
-	}
-	my $global = undef;
-	if ($self eq "EBox::Global") {
-		$global = EBox::Global->getInstance();
-	} elsif ($self->isa("EBox::Global")) {
-		$global = $self;
-	} else {
-		throw EBox::Exceptions::Internal("Incorrect call to ".
-		"EBox::Global modInstance(), the first parameter is not a class".
-		" nor an instance.");
-	}
+    my ($self, $name) = @_;
 
-	if ($name eq 'global') {
-		return $global;
-	}
-	my $modInstance  = $global->{'mod_instances'}->{$name};
-	if (defined($modInstance)) {
-		if (not ($global->isReadOnly() xor $modInstance->{'ro'})) {
-			return $modInstance;
-		}
-	}
-	
-	$global->modExists($name) or return undef;
-	my $classname = $global->get_string("modules/$name/class");
-	unless ($classname) {
-		throw EBox::Exceptions::Internal("Module '$name' ".
-				"declared, but it has no classname.");
-	}
-	eval "use $classname";
-	if ($@) {
-		throw EBox::Exceptions::Internal("Error loading ".
-						 "class: $classname");
-	}
-	if ($global->isReadOnly()) {
-		$global->{'mod_instances'}->{$name} =
-					$classname->_create(ro => 1);
-	} else {
-		$global->{'mod_instances'}->{$name} =
-						$classname->_create;
-	}
-	return $global->{'mod_instances'}->{$name};
+    if (!$self) {
+        throw EBox::Exceptions::Internal("Incorrect call to ".
+                                         "EBox::Global modInstance(), maybe it was called as an static".
+                                         " function instead of an instance method?");
+    }
+    if (not $name) {
+        throw EBox::Exceptions::MissingArgument(q{module's name});
+    }
 
+    my $global = undef;
+    if ($self eq "EBox::Global") {
+        $global = EBox::Global->getInstance();
+    } elsif ($self->isa("EBox::Global")) {
+        $global = $self;
+    } else {
+        throw EBox::Exceptions::Internal("Incorrect call to ".
+                                             "EBox::Global modInstance(), the first parameter is not a class".
+                                         " nor an instance.");
+    }
+    
+
+    if ($name eq 'global') {
+        return $global;
+    }
+
+    my $modInstance  = $global->{'mod_instances'}->{$name};
+    if (defined($modInstance)) {
+        if (not ($global->isReadOnly() xor $modInstance->{'ro'})) {
+            return $modInstance;
+                    }
+    }
+    
+    $global->modExists($name) or return undef;
+    my $classname = $global->get_string("modules/$name/class");
+    unless ($classname) {
+        throw EBox::Exceptions::Internal("Module '$name' ".
+                                         "declared, but it has no classname.");
+    }
+    eval "use $classname";
+    if ($@) {
+        throw EBox::Exceptions::Internal("Error loading ".
+                                         "class: $classname");
+    }
+    if ($global->isReadOnly()) {
+        $global->{'mod_instances'}->{$name} =
+            $classname->_create(ro => 1);
+    } else {
+        $global->{'mod_instances'}->{$name} =
+            $classname->_create;
+    }
+
+    return $global->{'mod_instances'}->{$name};
 }
 
 
@@ -680,5 +769,98 @@ sub init
 	EBox::init();
 }
 
+# Method: _runExecFromDir
+#
+#      Run executables files from a directory using
+#      <EBox::Sudo::command>. The execution will be done in lexical
+#      order
+#
+# Parameters:
+#
+#      dir - String the directory to search for executables
+#
+#      progress - <EBox::ProgressIndicator> to indicate the user how
+#      the actions are being performed
+#
+# Exceptions:
+#
+#      The ones launched by <EBox::Sudo::command>
+#
+sub _runExecFromDir
+{
+    my ($self, $dirPath, $progress) = @_;
+
+    unless ( -e $dirPath ) {
+        throw EBox::Exceptions::DataNotFound(data  => 'directory',
+                                             value => $dirPath);
+    }
+
+    opendir(my $dh, $dirPath);
+    my @execs = ();
+    while( my $file = readdir($dh) ) {
+        next unless ( -f "${dirPath}/$file" or -l "${dirPath}/$file");
+        next unless ( -x "${dirPath}/$file" );
+        push(@execs, "${dirPath}/$file");
+    }
+    closedir($dh);
+
+    # Sorting lexically the scripts to execute
+    @execs = sort(@execs);
+
+    if ( @execs > 0 ) {
+        EBox::info("Running executable files from $dirPath");
+        foreach my $exec (@execs) {
+            try {
+                EBox::info("Running $exec");
+                # Progress indicator stuff
+                $progress->setMessage(__x('running {scriptName} script',
+                                          scriptName => scalar(File::Basename::fileparse($exec))));
+                $progress->notifyTick();
+                my $output = EBox::Sudo::command($exec);
+                if ( @{$output} > 0) {
+                    EBox::info("Output from $exec: @{$output}");
+                }
+            } catch EBox::Exceptions::Command with {
+                my ($exc) = @_;
+                my $msg = "Command $exec failed its execution\n"
+                  . 'Output: ' . @{$exc->output()} . "\n"
+                  . 'Error: ' . @{$exc->error()} . "\n"
+                  . 'Return value: ' . $exc->exitValue();
+                EBox::error($msg);
+            } otherwise {
+                my ($exc) = @_;
+                EBox::error("Error executing $exec: $exc");
+            };
+        }
+    }
+
+}
+
+# Method: _nScripts
+#
+# Parameters:
+#
+#     array - the dir path to count executable files
+# 
+# Returns:
+#
+#     Integer - number of executable scripts in pre/post dirs
+#
+sub _nScripts
+{
+    my ($self, @dirPaths) = @_;
+
+    my $nScripts = 0;
+    foreach my $dirPath (@dirPaths) {
+        opendir(my $dh, $dirPath);
+        while( my $file = readdir($dh) ) {
+            next unless ( -f "${dirPath}/$file" or -l "${dirPath}/$file");
+            next unless ( -x "${dirPath}/$file" );
+            $nScripts++;
+        }
+        closedir($dh);
+    }
+    return $nScripts;
+}
 
 1;
