@@ -38,9 +38,11 @@ use EBox::DBEngineFactory;
 use EBox::Logs::Model::ConfigureLogDataTable;
 use EBox::Logs::Model::ForcePurge;
 use EBox::Logs::Composite::ConfigureLog;
+use EBox::Service;
 
 use POSIX qw(ceil);
 
+use constant LOG_DAEMON => 'ebox.loggerd';
 use constant IMAGEPATH => EBox::Config::tmp . '/varimages';
 use constant PIDPATH => EBox::Config::tmp . '/pids/';
 use constant ENABLED_LOG_CONF_DIR => EBox::Config::conf  . '/logs';;
@@ -64,9 +66,35 @@ sub _create
 	return $self;
 }
 
+
+# Method: actions
+#
+# 	Override EBox::ServiceModule::ServiceInterface::actions
+#
+sub actions
+{
+	return [ 
+	{
+		'action' => __('Create logs database'),
+		'reason' => __('eBox store its logs in the database'),
+		'module' => 'logs'
+	}
+    ];
+}
+
+
+# Method: enableActions 
+#
+# 	Override EBox::ServiceModule::ServiceInterface::enableActions
+#
+sub enableActions
+{
+    EBox::Sudo::root(EBox::Config::share() . '/ebox/ebox-logs-enable');
+}
+
 #  Method: serviceModuleName
 #
-#   Override EBox::ServiceModule::ServiceInterface::servivceModuleName
+#   Override EBox::ServiceModule::ServiceInterface::serviceModuleName
 #
 sub serviceModuleName
 {
@@ -80,13 +108,16 @@ sub _regenConfig
 
 	$self->_saveEnabledLogs();
 	_stopService();
-	system(EBox::Config::pkgdata . 'ebox-loggerd');
+
+	return unless ($self->isEnabled());
+
+	EBox::Service::manage(LOG_DAEMON, 'start');
 }
 
 sub _stopService
 {
-	if (-f PIDPATH . "loggerd.pid") {
-        	system(EBox::Config::pkgdata . 'ebox-kill-pid loggerd');
+	if (EBox::Service::running(LOG_DAEMON)) {
+	    EBox::Service::manage(LOG_DAEMON, 'stop');
 	}
 }
 
@@ -432,6 +463,8 @@ sub search {
 		   'Table {table} does not exist', 'table' => $table));
 	}
 
+	$self->{'sqlselect'} = { };
+
 	$self->_addTableName($table);
 	if (_checkValidDate($from)) {
 		$self->_addDateFilter($timecol, $from, '>');
@@ -439,7 +472,7 @@ sub search {
 	if (_checkValidDate($to)) {
 		$self->_addDateFilter($timecol, $to, '<');
 	}
-	if ($filters) {
+	if ($filters and %{$filters}) {
 		foreach my $field (keys %{$filters}) {
 			unless (exists $tableinfo->{'titles'}->{$field}) {
 			   throw  EBox::Exceptions::Internal(
@@ -472,11 +505,13 @@ sub search {
 	
 	my $offset = $page * $pagesize;
 	$self->_addPager($offset, $pagesize);
+        $self->_addOrder("$timecol DESC");
+
 	$self->_addSelect('*');
+        
+
 	my @ret = @{$dbengine->query($self->_sqlStmnt())};
 	
-	$self->{'sqlselect'} = undef;
-
 	my $hashret = {
 		'totalret' => $tcount,
 		'arrayret' => \@ret
@@ -537,10 +572,18 @@ sub _addDateFilter
 
 sub _addPager
 {
+    my ($self, $offset, $limit) = @_;
+    $self->{'sqlselect'}->{'offset'} = $offset;
+    $self->{'sqlselect'}->{'limit'} = $limit;
+}
+
+
+sub _addOrder
+{
+    my ($self, $order) = @_;
+
+    $self->{sqlselect}->{order} = $order;
 
-	my ($self, $offset, $limit) = @_;
-	$self->{'sqlselect'}->{'offset'} = $offset;
-	$self->{'sqlselect'}->{'limit'} = $limit;
 }
 
 sub _addTableName
@@ -577,7 +620,7 @@ sub _sqlStmnt {
 	
 	if ($sql->{'regexp'}) {
 		foreach my $field (keys %{$sql->{'regexp'}}) {
-			$stmt .= "$and $field ~ ? ";
+			$stmt .= "$and CAST($field as text) ~ ? ";
 			$and = 'AND';
 			push @params, $sql->{'regexp'}->{$field};
 		}
@@ -590,6 +633,10 @@ sub _sqlStmnt {
 		}
 	}
 
+        if ($sql->{order}) {
+            $stmt .= 'ORDER BY ' . $sql->{order} . ' ';
+        }
+
         $stmt .= "OFFSET ? LIMIT ?";
 	push @params, $sql->{'offset'}, $sql->{'limit'};
 
@@ -736,6 +783,21 @@ sub _facilitiesForDiskUsage
 	 };
 }
 
+# Method: forcePurge
+#
+#      Force to purge every table used to log data in eBox given a
+#      timestamp
+#
+# Parameters:
+#
+#      lifetime - Int the allowed data not to purge should be
+#                 timestamped before this limit which is set in hours
+#
+# Exceptions:
+#
+#      <EBox::Exceptions::External> - thrown if the lifetime is not a
+#      positive number
+#
 sub forcePurge
 {
   my ($self, $lifetime) = @_;
@@ -748,11 +810,24 @@ sub forcePurge
 
   foreach my $tableInfo ( values %{ $self->getAllTables } ) {
     my $table = $tableInfo->{tablename};
-    $self->_purgeTable($table, $thresholdDate);
+    my $timeCol = $tableInfo->{timecol};
+    $self->_purgeTable($table, $timeCol, $thresholdDate);
   }
-  
 }
 
+# Method: purge
+#
+#      Purge every table used to log data in eBox with the threshold
+#      lifetime defined by 'lifetime' field in
+#      <EBox::Logs::Model::ConfigureLogDataTable> model
+#
+#     This method is called by a cron job.
+#
+# Exceptions:
+#
+#      <EBox::Exceptions::External> - thrown if the lifetime is not a
+#      positive number
+#
 sub purge
 {
   my ($self) = @_;
@@ -761,27 +836,26 @@ sub purge
 
   # get the threshold date for each domain
   foreach my $row_r ( @{ $self->configureLogModel->rows() } ) {
-    my $valuesHash = $row_r->{plainValueHash};
-    my $lifeTime = $valuesHash->{'lifeTime'};
+    my $lifeTime = $row_r->valueByName('lifeTime');
     
     # if lifeTime == 0, it should never expire
     $lifeTime or
       next;
 
     my $threshold = $self->_thresholdDate($lifeTime);
-    $thresholdByDomain{$valuesHash->{'domain'}} = $threshold;
+    $thresholdByDomain{$row_r->valueByName('domain')} = $threshold;
   }
 
-  
   # purge each domain
   my $tables = $self->getAllTables();
   while (my ($domain, $threshold) = each %thresholdByDomain) {
     my $table = $tables->{$domain}->{tablename};
-    $self->_purgeTable($table, $threshold);
+    my $timeCol = $tables->{$domain}->{timecol};
+    $self->_purgeTable($table, $timeCol, $threshold);
   }
 }
 
-
+# Transform an hour into a localtime
 sub _thresholdDate
 {
   my ($self, $lifeTime) = @_;
@@ -792,11 +866,12 @@ sub _thresholdDate
   return scalar localtime($threshold);
 }
 
-sub _purgeTable
+# Do perform the purge in a table
+sub _purgeTable #(tablename, timecolumn, thresholdDate)
 {
-  my ($self, $table, $thresholdDate) = @_;
-  
-  my $sqlStatement = "DELETE FROM $table WHERE timestamp < '$thresholdDate'";
+  my ($self, $table, $timeCol, $thresholdDate) = @_;
+
+  my $sqlStatement = "DELETE FROM $table WHERE $timeCol < '$thresholdDate'";
   my $dbengine = EBox::DBEngineFactory::DBEngine();
   $dbengine->query($sqlStatement);
 }
