@@ -35,6 +35,7 @@
 #
 
 package EBox::Model::Composite;
+use base 'EBox::Model::Component';
 
 use strict;
 use warnings;
@@ -59,6 +60,8 @@ use Perl6::Junction qw(any);
 # Constants
 use constant LAYOUTS => qw(top-bottom tabbed select);
 
+
+
 # Group: Public methods
 
 # Constructor: new
@@ -419,6 +422,23 @@ sub printableName
 
   }
 
+# Method: pageTitle
+#
+#       Get the i18ned name of the page where the model is contained, if any
+#
+# Returns:
+#
+#   string
+#
+sub pageTitle 
+  {
+
+      my ($self) = @_;
+
+      return $self->printableName();
+
+  }
+
 # Method: precondition
 #
 #       Check if the composite has enough data to be manipulated, that
@@ -746,6 +766,9 @@ sub _setDescription
       }
 
       if ( exists ($description->{name})) {
+          $description->{name} or
+          throw EBox::Exceptions::Internal('name for composite cannot be empty');
+
           $self->{name} = delete ( $description->{name} );
       }
 
@@ -758,6 +781,11 @@ sub _setDescription
       }
 
       if ( exists ($description->{selectMessage})) {
+          ($self->{layout} eq 'select')
+              or throw EBox::Exceptions::Internal(
+                     'Cannot use selectMessage when layout is not of select type'
+                                                 );
+
           $self->{selectMessage} = delete ( $description->{selectMessage} );
       }
 
