@@ -27,6 +27,7 @@ use strict;
 use warnings;
 
 # eBox uses
+use EBox::Model::Row;
 use EBox::Exceptions::Internal;
 use EBox::Gettext;
 
@@ -37,8 +38,8 @@ use Perl6::Junction qw(any);
 use NEXT;
 
 # Core modules
+use Clone;
 use Error qw(:try);
-use Clone qw(clone);
 
 # Group: Public methods
 
@@ -73,6 +74,29 @@ sub new
 
   }
 
+# Method: _checkTable
+#
+#  Method overriden to add some checks
+#
+#  Overrides:
+#    EBox::Model::DataTable::_checkTable
+sub _checkTable
+{
+    my ($self, $table) = @_;
+
+    $self->SUPER::_checkTable($table);
+
+    my @unallowedSuperParams = qw(sortedBy order);
+    foreach my $param (@unallowedSuperParams) {
+        if (exists $table->{$param}) {
+            throw EBox::Exceptions::Internal(
+
+                                            );
+        }
+    }
+
+}
+
 # Method: addRow
 #
 #       This method has no sense since it has just one row. To fill
@@ -297,7 +321,7 @@ sub setRow
 
       my $changedData;
       for (my $i = 0; $i < @newValues ; $i++) {
-          my $newData = clone($newValues[$i]);
+          my $newData = $newValues[$i]->clone();
           $newData->setMemValue(\%params);
 
           $changedData->{$newData->fieldName()} = $newData;
@@ -367,7 +391,7 @@ sub set
         throw EBox::Exceptions::MissingArgument('Missing parameters to set their value');
     }
 
-    my $typedParams = $self->_fillTypes(\%params);
+    my $typedParams = $self->_fillTypes(\%params, 1);
 
     $self->setTypedRow(0, $typedParams, force => $force,
                        readOnly => $readOnly);
@@ -383,36 +407,13 @@ sub set
 #       <EBox::Model::DataTable::rows>
 #
 sub rows
-  {
+{
+    my ($self) = @_;
 
-      my ($self) = @_;
+    return [ $self->_row() ];
+}
 
-      return [ $self->_row() ];
 
-  }
-
-# Method: printableValueRows
-#
-#       Return a list containing the table rows and the printable
-#       value of every field. It makes no sense in an one-rowed table.
-#
-# Overrides:
-#
-#       <EBox::Model::DataTable::printableValueRows>
-#
-# Exceptions:
-#
-#       <EBox::Exceptions::Internal> - thrown since it has no sense in
-#       an one-rowed table
-#
-#sub printableValueRows
-#  {
-#
-#      throw EBox::Exceptions::Internal('It cannot return more than one row in an ' .
-#                                       'one-rowed table');
-#
-#  }
-#
 # Method: order
 #
 #       Get the keys order in an array ref. It makes no sense in an one-rowed table.
@@ -427,11 +428,30 @@ sub rows
 #       an one-rowed table
 #
 sub order
-  {
+{
 
       throw EBox::Exceptions::Internal('It has no sense order in an one-rowed table');
 
-  }
+}
+
+
+# Method: sortedBy
+#
+#       Return the field name which is used by model to sort rows when
+#       the model is not ordered. It makes no sense in an one-rowed table.
+#
+# Returns:
+#
+#       String - field name used to sort the rows
+#
+sub sortedBy
+{
+
+    throw EBox::Exceptions::Internal(
+         'It has no sense sortedBy in an one-rowed table'
+                                    );
+
+}
 
 # Method: rowUnique
 #
@@ -627,7 +647,7 @@ sub AUTOLOAD
       # Get the attribute and its suffix if any <attr>(Value|PrintableValue|Type|)
       my ($attr, $suffix) = $methodName =~ m/^(.+?)(Value|PrintableValue|Type|)$/;
 
-      unless ( any( keys ( %{$row->{valueHash}} ) ) eq $attr ) {
+      unless ( any( keys ( %{$row->hashElements()} ) ) eq $attr ) {
           # Try with the parent autoload
           return $self->NEXT::ACTUAL::AUTOLOAD(@params);
       }
@@ -639,11 +659,11 @@ sub AUTOLOAD
       }
 
       if ( $suffix eq 'Value' ) {
-          return $row->{plainValueHash}->{$attr};
+          return $row->valueByName($attr);
       } elsif ( $suffix eq 'PrintableValue' ) {
-          return $row->{printableValueHash}->{$attr};
+          return $row->printableValueByName($attr);
       } elsif ( $suffix eq 'Type' ) {
-          return $row->{valueHash}->{$attr};
+          return $row->elementByName($attr);
       }
 
       return;
@@ -734,7 +754,7 @@ sub _addRow
       my @userData;
       my $userData;
       foreach my $type (@{$self->table()->{'tableDescription'}}) {
-          my $data = clone($type);
+          my $data = $type->clone();
           $data->setMemValue(\%params);
 
           push (@userData, $data);
@@ -771,12 +791,18 @@ sub _addTypedRow
     my $gconfmod = $self->{'gconfmodule'};
     my $readOnly = delete $optParams{'readOnly'};
 
+    my $row =  EBox::Model::Row->new(dir => $dir, gconfmodule => $gconfmod);
+    $row->setReadOnly($readOnly);
+    $row->setModel($self);
+    $row->setId('dummy');
+
     # Check compulsory fields
     $self->_checkCompulsoryFields($paramsRef);
 
     $self->validateTypedRow('add', $paramsRef, $paramsRef);
 
     foreach my $data (values ( %{$paramsRef} )) {
+        $row->addElement($data);
         $data->storeInGConf($gconfmod, "$dir");
         $data = undef;
     }
@@ -803,14 +829,16 @@ sub _setTypedRow
 
     my $dir = $self->{'directory'};
     my $gconfmod = $self->{'gconfmodule'};
+    
+    
 
     my $oldRow = $self->row();
-    my $oldValues = $oldRow->{'valueHash'};
+    my $oldValues = $oldRow->hashElements();
 
     my @setterTypes = @{$self->setterTypes()};
 
     my $changedData = { };
-    my $allData = $self->row()->{valueHash};
+    my $allData = $self->row()->hashElements();
     my @changedData = ();
     foreach my $paramName (keys %{$paramsRef}) {
         unless ( exists ( $oldValues->{$paramName} )) {
@@ -883,53 +911,27 @@ sub _row
 
       my $dir = $self->{'directory'};
       my $gconfmod = $self->{'gconfmodule'};
-      my $row = {};
 
+      
       unless ($gconfmod->dir_exists("$dir")) {
           # Return default values instead
           return $self->_defaultRow();
       }
+      
+      my $row =  EBox::Model::Row->new(dir => $dir, gconfmodule => $gconfmod);
+      $row->setModel($self);
 
       my @values;
       $self->{'cacheOptions'} = {};
       my $gconfData = $gconfmod->hash_from_dir("$dir");
-      $row->{'readOnly'} = $gconfData->{'readOnly'};
+      $row->setReadOnly($gconfData->{'readOnly'});
       foreach my $type (@{$self->table()->{'tableDescription'}}) {
-          my $data = clone($type);
-          $data->restoreFromHash($gconfData);
-          $data->setRow($row);
-          $data->setModel($self);
-
-          # TODO Rework the union select options thing
-          #      this code just sucks. Modify Types to do something
-          #      nicer 
-          if ($data->type() eq 'union') {
-              # FIXME: Check if we can avoid this
-              $row->{'plainValueHash'}->{$data->selectedType} =
-                $data->value();
-              $row->{'printableValueHash'}->{$data->selectedType} =
-                $data->printableValue();
-          }
-          if ($data->type eq 'hasMany') {
-              my $fieldName = $data->fieldName();
-              $data->setDirectory("$dir/$fieldName");
-          }
-          if ($data->type eq 'hasMany') {
-              my $fieldName = $data->fieldName();
-              $data->setDirectory("$dir/$fieldName");
-          }
-
-          push (@values, $data);
-          $row->{'valueHash'}->{$type->fieldName()} = $data;
-          $row->{'plainValueHash'}->{$type->fieldName()} = $data->value();
-          $row->{'printableValueHash'}->{$type->fieldName()} =
-            $data->printableValue();
+          my $element = $type->clone();
+          $element->restoreFromHash($gconfData);
+          $row->addElement($element);
       }
-
-      $row->{'values'} = \@values;
       # Dummy id for dataform
-      $row->{'id'} = 'dummy';
-
+      $row->setId('dummy');
       return $row;
 
   }
@@ -941,37 +943,15 @@ sub _defaultRow
       my ($self) = @_;
 
       my $dir = $self->{'directory'};
-      my $row = {};
-      my @values = ();
+      my $gconfmod = $self->{'gconfmodule'};
+      my $row = EBox::Model::Row->new(dir => $dir, gconfmodule => $gconfmod);
+      $row->setModel($self);
+      $row->setId('dummy');
 
       foreach my $type (@{$self->table()->{'tableDescription'}}) {
-          my $data = clone($type);
-
-          if ($data->type() eq 'union') {
-            # FIXME: Check if we can avoid this
-              $row->{'plainValueHash'}->{$data->selectedType} =
-                $data->value();
-              $row->{'printableValueHash'}->{$data->selectedType} =
-                $data->printableValue();
-          }
-          if ($data->type eq 'hasMany') {
-              my $fieldName = $data->fieldName();
-              $data->setDirectory("$dir/$fieldName");
-          }
-          if ($data->type eq 'hasMany') {
-              my $fieldName = $data->fieldName();
-              $data->setDirectory("$dir/$fieldName");
-          }
-
-          push (@values, $data);
-          $row->{'valueHash'}->{$type->fieldName()} = $data;
-          $row->{'plainValueHash'}->{$type->fieldName()} = $data->value();
-          $row->{'printableValueHash'}->{$type->fieldName()} =
-            $data->printableValue();
+          my $element = $type->clone();
+          $row->addElement($element);
       }
-
-      $row->{'values'} = \@values;
-
       return $row;
 
   }
