@@ -33,6 +33,8 @@ use EBox::Exceptions::Internal;
 use EBox::Exceptions::DataNotFound;
 use Error qw(:try);
 
+# Constant
+use constant MAX_INT => 32767;
 
 # Singleton variable
 my $_instance = undef;
@@ -49,6 +51,7 @@ sub _new
 
     $self->{'version'} = $self->_version();
     $self->_setUpModels();
+    $self->_setRelationship();
 
     return $self;
 }
@@ -114,12 +117,17 @@ sub model
     my ($self, $path) = @_;
 
 
-    unless ( defined ( $path )) {
+    unless (  $path ) {
         throw EBox::Exceptions::MissingArgument('path');
     }
 
     my ($moduleName, $modelName, @parameters) = grep { $_ ne '' } split ( '/', $path);
-    if ( not defined ( $modelName ) and $path =~ m:/: ) {
+    
+    if (not $moduleName) {
+        throw EBox::Exceptions::Internal('Invalid path');
+    }
+
+    if ( ( not $modelName ) and $path =~ m:/: ) {
         throw EBox::Exceptions::Internal('One element is given and ' .
                                          'slashes are given. The valid format ' .
                                          'requires no slashes, sorry');
@@ -130,6 +138,8 @@ sub model
     if ( $self->_hasChanged() ) {
         $self->_setUpModels();
         $self->{'version'} = $self->_version();
+        $self->_setRelationship();
+
     }
 
     unless ( defined ( $modelName )) {
@@ -143,13 +153,13 @@ sub model
             # There are at least one parameter
             return $self->_chooseModelUsingParameters($path);
         } else {
-		my $nModels = @{$self->{'models'}->{$moduleName}->{$modelName}};
-		if ((@parameters and $parameters[0] eq '*') or $nModels > 1) {
-			return $self->{'models'}->{$moduleName}->{$modelName};
-		} else {
-			return 
-			  $self->{'models'}->{$moduleName}->{$modelName}->[0];
-		}
+            my $nModels = @{$self->{'models'}->{$moduleName}->{$modelName}};
+            if ((@parameters and $parameters[0] eq '*') or $nModels > 1) {
+                return $self->{'models'}->{$moduleName}->{$modelName};
+            } else {
+                return 
+                    $self->{'models'}->{$moduleName}->{$modelName}->[0];
+            }
         }
     } else {
         throw EBox::Exceptions::DataNotFound( data  => 'model',
@@ -341,11 +351,11 @@ sub modelActionTaken
     throw EBox::Exceptions::MissingArgument("action") unless (defined($action));
     throw EBox::Exceptions::MissingArgument("row") unless (defined($row));
 
-    if ( defined $row->{'id'} ) {
-        EBox::debug("$model has taken action '$action' on row $row->{'id'}");
-    } else {
-        EBox::debug("$model has taken action '$action' on row");
-    }
+    # if ( defined $row->{'id'} ) {
+    #    EBox::debug("$model has taken action '$action' on row $row->{'id'}");
+    # } else {
+    #    EBox::debug("$model has taken action '$action' on row");
+    # }
     # return '' unless (exists $self->{'notifyActions'}->{$model});
 
     my $strToRet = '';
@@ -443,19 +453,19 @@ sub removeRowsUsingId
 #
 sub warnIfIdIsUsed
 {
-	my ($self, $modelName, $id) = @_;
+    my ($self, $modelName, $id) = @_;
 
-	my $tablesUsing;
+    my $tablesUsing;
 
-	for my $name  (values %{$self->modelsUsingId($modelName, $id)}) {
-		$tablesUsing .= '<br> - ' .  $name ;
-	}
+    for my $name  (values %{$self->modelsUsingId($modelName, $id)}) {
+        $tablesUsing .= '<br> - ' .  $name ;
+    }
 
-	if ($tablesUsing) {
-		throw EBox::Exceptions::DataInUse(
-			__('The data you are removing is being used by
-			the following sections:') . '<br>' . $tablesUsing);
-	}
+    if ($tablesUsing) {
+        throw EBox::Exceptions::DataInUse(
+                __('The data you are removing is being used by
+                    the following sections:') . '<br>' . $tablesUsing);
+    }
 }
 
 # Method: warnOnChangeOnId
@@ -521,8 +531,8 @@ sub markAsChanged
 
     my $oldVersion = $self->_version();
     $oldVersion = 0 unless ( defined ( $oldVersion ));
-    $oldVersion++;
-    $gl->set_int('model_manager/version', $oldVersion);
+    $oldVersion = ($oldVersion + 1) % MAX_INT;
+    $gl->st_set_int('model_manager/version', $oldVersion);
 
 }
 
@@ -553,6 +563,24 @@ sub _setUpModels
     }
 }
 
+# Method: _setRelationship
+#
+#   (PRIVATE)
+#
+#   Set the relationship between models and submodels
+#
+sub _setRelationship
+{
+    my ($self) = @_;
+
+    # Set parent models given by hasMany relationships
+    for my $childName (keys %{$self->{'childOf'}}) {
+        $self->model($childName)->setParent($self->{'childOf'}->{$childName});
+    }
+
+
+}
+
 # Method: _setUpModelsFromProvider
 #
 #   (PRIVATE)
@@ -571,7 +599,12 @@ sub _setUpModelsFromProvider
 
     try {
         for my $model (@{$provider->models()}) {
-            push ( @{$self->{'models'}->{$provider->name()}->{$model->tableName()}}, $model);
+	    my $moduleName = $provider->name();
+	    my $modelName = $model->tableName();
+	    $modelName or 
+		throw EBox::Exceptions::Internal("Invalid model name $modelName");
+
+            push ( @{$self->{'models'}->{$moduleName}->{$modelName}}, $model);
         }
         for my $model (@{$provider->reloadModelsOnChange()}) {
             push ( @{$self->{'reloadActions'}->{$model}}, $provider->name());
@@ -588,12 +621,15 @@ sub _setUpModelsFromProvider
         foreach my $model ( @{$self->{'models'}->{$provider->name()}->{$modelKind}} ) {
             my $tableDesc = $model->table()->{'tableDescription'};
             my $localModelName = $model->contextName();
-            for my $type (@{$self->_fetchSelectTypes($tableDesc)}) {
+            my $dependentTypes = $self->_fetchDependentTypes($tableDesc);
+            for my $type (@{$dependentTypes->{'select'}}) {
                 my $foreignModel;
                 try {
                     $foreignModel = $type->foreignModel();
                 } otherwise {
+                    my ($exc) = @_;
                     EBox::warn("Skipping " . $type->fieldName() . " to fetch model");
+                    EBox::warn("Error: $exc");
                 };
                 next unless (defined($foreignModel));
                 my $foreignModelName = $foreignModel->contextName();
@@ -602,6 +638,19 @@ sub _setUpModelsFromProvider
                 push (@{$currentHasOne{$localModelName}}, $type->fieldName());
                 $self->{'hasOneReverse'}->{$foreignModelName} = \%currentHasOne;
             }
+            for my $type (@{$dependentTypes->{'hasMany'}}) {
+                my $foreignModel;
+                try {
+                    $foreignModel = $type->foreignModel();
+                } otherwise {
+                    my ($exc) = @_;
+                    EBox::warn("Skipping " . $type->fieldName() . " to fetch model");
+                    EBox::warn("Error: $exc");
+                };
+                next unless (defined($foreignModel) and $foreignModel ne '');
+                $self->{'childOf'}->{$foreignModel} = $model;
+            }
+
         }
     }
 
@@ -644,12 +693,15 @@ sub _modelsWithHasOneRelation
 }
 
 
-# Method: _fetchSelectTypes
+# Method: _fetchDependentTypes
 #
 # 	(PRIVATE)
 #
-#   Given a table description it returns all its types which are
-#   <EBox::Types::Select>
+#   Given a table description it returns  types which depends on other
+#   modules. Those are:
+#
+#       <EBox::Types::Select>
+#       <EBox::Types::HasMany>
 #
 # Parameters:
 #
@@ -661,22 +713,31 @@ sub _modelsWithHasOneRelation
 #
 #   Array ref containing the types
 #
-sub _fetchSelectTypes
+sub _fetchDependentTypes
 {
     my ($self, $tableDescription) = @_;
 
     my @selectTypes;
+    my @hasManyTypes;
     foreach my $type (@{$tableDescription}) { 
         if ($type->type() eq 'union') {
             for my $subtype (@{$type->subtypes()}) {
-                push (@selectTypes, $subtype) if ($subtype->type() eq 'select');
+                 if ($subtype->type() eq 'select') {
+                    push (@selectTypes, $subtype);
+                }
+                if ($subtype->type() eq 'hasMany') {
+                    push (@hasManyTypes, $subtype);
+                }
             }
         } elsif ($type->type() eq 'select') {
             push (@selectTypes, $type);
+        } elsif ($type->type() eq 'hasMany') {
+            push (@hasManyTypes, $type);
         }
     }
     
-    return \@selectTypes;
+    return { 'select' => \@selectTypes,
+             'hasMany' => \@hasManyTypes };
 }
 
 
@@ -821,8 +882,17 @@ sub _hasChanged
 
     my ($self) = @_;
 
-    return $self->{'version'} < $self->_version();
+    my $actualVersionNotDefined = not defined $self->{'version'};
+    my $gconfVersionNotDefined  = not defined $self->_version();
 
+    if ($actualVersionNotDefined and $gconfVersionNotDefined) {
+        return undef;
+    }
+    elsif ($actualVersionNotDefined or $gconfVersionNotDefined) {
+        return 1;
+    }
+
+    return ($self->{'version'} != $self->_version());
 }
 
 # Method: _version
@@ -842,7 +912,7 @@ sub _version
 
     my $gl = EBox::Global->getInstance();
 
-    return $gl->get_int('model_manager/version');
+    return $gl->st_get_int('model_manager/version');
 
 }
 
