@@ -148,8 +148,8 @@ sub menu
 	$folder->add(new EBox::Menu::Item('url' => 'EBox/Halt',
 					  'text' => __('Halt/Reboot')));
 
-	$folder->add(new EBox::Menu::Item('url' => 'EBox/Bug',
-					  'text' => __('Bug report')));
+#	$folder->add(new EBox::Menu::Item('url' => 'EBox/Bug',
+#					  'text' => __('Bug report')));
 
 
 
