@@ -71,7 +71,7 @@ sub _table
         (
          new EBox::Types::IPAddr(
                                  'fieldName' => 'compulsory_addr',
-                                 'printableName' => __('Compulsory IP Address'),
+                                 'printableName' => 'Compulsory IP Address',
                                  'class' => 'tcenter',
                                  'size' => '12',
                                  'editable' => 1,
@@ -79,7 +79,7 @@ sub _table
                                 ),
          new EBox::Types::IPAddr(
                                  'fieldName' => 'optional_addr',
-                                 'printableName' => __('Optional IP Address'),
+                                 'printableName' => 'Optional IP Address',
                                  'class' => 'tcenter',
                                  'size' => '12',
                                  'editable' => 1,
@@ -87,7 +87,7 @@ sub _table
                                 ),
          new EBox::Types::Boolean(
                                   'fieldName' => 'compulsory_boolean',
-                                  'printableName' => __('Compulsory Boolean'),
+                                  'printableName' => 'Compulsory Boolean',
                                   'class' => 'tcenter',
                                   'size' => '1',
                                   'editable' => 1,
@@ -95,7 +95,7 @@ sub _table
                                 ),
          new EBox::Types::Boolean(
                                   'fieldName' => 'optional_boolean',
-                                  'printableName' => __('Optional Boolean'),
+                                  'printableName' => 'Optional Boolean',
                                   'class' => 'tcenter',
                                   'size' => '1',
                                   'editable' => 1,
@@ -103,7 +103,7 @@ sub _table
                                  ),
          new EBox::Types::Int(
                                   'fieldName' => 'compulsory_int',
-                                  'printableName' => __('Compulsory Integer'),
+                                  'printableName' => 'Compulsory Integer',
                                   'class' => 'tcenter',
                                   'size' => '1',
                                   'editable' => 1,
@@ -111,7 +111,7 @@ sub _table
                                 ),
          new EBox::Types::Int(
                               'fieldName' => 'optional_int',
-                              'printableName' => __('Optional Integer'),
+                              'printableName' => 'Optional Integer',
                               'class' => 'tcenter',
                               'size' => '1',
                               'editable' => 1,
@@ -119,7 +119,7 @@ sub _table
                              ),
          new EBox::Types::Select(
                                  'fieldName' => 'compulsory_select',
-                                 'printableName' => __('Compulsory Select'),
+                                 'printableName' => 'Compulsory Select',
                                  'class' => 'tcenter',
                                  'size' => '1',
                                  'editable' => 1,
@@ -128,7 +128,7 @@ sub _table
                                 ),
 #         new EBox::Types::Select(
 #                                 'fieldName' => 'unique_select',
-#                                 'printableName' => __('Unique Select'),
+#                                 'printableName' => 'Unique Select',
 #                                 'class' => 'tcenter',
 #                                 'size' => '1',
 #                                 'editable' => 1,
@@ -138,7 +138,7 @@ sub _table
 #                                 ),
 #         new EBox::Types::Select(
 #                                 'fieldName'     => 'foreign_select',
-#                                 'printableName' => __('Foreign Select Object'),
+#                                 'printableName' => 'Foreign Select Object',
 #                                 'foreignModel'  => \&objectModelCallback,
 #                                 'foreignField'  => 'name',
 #                                 'class'         => 'tcenter',
@@ -146,7 +146,7 @@ sub _table
 #                                ),
          new EBox::Types::Text(
                                'fieldName' => 'compulsory_text',
-                               'printableName' => __('Compulsory Text'),
+                               'printableName' => 'Compulsory Text',
                                'class' => 'tcenter',
                                'size' => '10',
                                'editable' => 1,
@@ -154,7 +154,7 @@ sub _table
                               ),
          new EBox::Types::Text(
                                'fieldName' => 'optional_text',
-                               'printableName' => __('Optional Text'),
+                               'printableName' => 'Optional Text',
                                'class' => 'tcenter',
                                'size' => '10',
                                'editable' => 1,
@@ -162,7 +162,7 @@ sub _table
                               ),
          new EBox::Types::MACAddr(
                                'fieldName' => 'compulsory_mac',
-                               'printableName' => __('Compulsory MAC Address'),
+                               'printableName' => 'Compulsory MAC Address',
                                'class' => 'tcenter',
                                'size' => '10',
                                'editable' => 1,
@@ -170,7 +170,7 @@ sub _table
                               ),
          new EBox::Types::MACAddr(
                                'fieldName' => 'optional_mac',
-                               'printableName' => __('Optional MAC address'),
+                               'printableName' => 'Optional MAC address',
                                'class' => 'tcenter',
                                'size' => '10',
                                'editable' => 1,
@@ -178,7 +178,7 @@ sub _table
                               ),
          new EBox::Types::Link(
                                'fieldName' => 'optional_link',
-                               'printableName' => __('Optional Link'),
+                               'printableName' => 'Optional Link',
                                'class' => 'tcenter',
                                'size' => '1',
                                'optional' => 1,
@@ -187,7 +187,7 @@ sub _table
                               ),
          new EBox::Types::Password(
                                    'fieldName' => 'compulsory_password',
-                                   'printableName' => __('Compulsory Password'),
+                                   'printableName' => 'Compulsory Password',
                                    'class' => 'tcenter',
                                    'size' => '10',
                                    'editable' => 1,
@@ -197,7 +197,7 @@ sub _table
                                   ),
          new EBox::Types::Password(
                                    'fieldName' => 'optional_password',
-                                   'printableName' => __('Optional Password'),
+                                   'printableName' => 'Optional Password',
                                    'class' => 'tcenter',
                                    'size' => '10',
                                    'editable' => 1,
@@ -206,7 +206,7 @@ sub _table
                                   ),
          new EBox::Types::PortRange(
                                    'fieldName' => 'port_range',
-                                   'printableName' => __('Port range'),
+                                   'printableName' => 'Port range',
                                    'class' => 'tcenter',
                                    'size' => '5',
                                    'editable' => 1,
@@ -214,7 +214,7 @@ sub _table
                                   ),
          new EBox::Types::Union(
                                 'fieldName'     => 'union',
-                                'printableName' => __('Union'),
+                                'printableName' => 'Union',
                                 'class'         => 'tcenter',
                                 'size'          => 10,
                                 'editable'      => 1,
@@ -222,28 +222,28 @@ sub _table
                                 [
                                  new EBox::Types::Text(
                                                        'fieldName' => 'foo',
-                                                       'printableName' => __('Foo'),
+                                                       'printableName' => 'Foo',
                                                        'editable'      => 1,
                                                       ),
                                  new EBox::Types::PortRange(
                                                             'fieldName' => 'bar',
-                                                            'printableName' => __('Bar'),
+                                                            'printableName' => 'Bar',
                                                             'editable'      => 1,
                                                            ),
                                  new EBox::Types::IPAddr(
                                                          'fieldName' => 'baz',
-                                                         'printableName' => __('Baz'),
+                                                         'printableName' => 'Baz',
                                                          'editable' => 1,
                                                          ),
                                  new EBox::Types::Union::Text(
                                                               'fieldName' => 'others',
-                                                              'printableName' => __('Other option'),
+                                                              'printableName' => 'Other option',
                                                              ),
                                 ]
                                ),
          new EBox::Types::InverseMatchSelect(
                                              'fieldName' => 'inverse_select',
-                                             'printableName' => __('Inverse Match Select'),
+                                             'printableName' => 'Inverse Match Select',
                                              'class' => 'tcenter',
                                              'size' => '11',
                                              'editable' => 1,
@@ -252,7 +252,7 @@ sub _table
                                             ),
          new EBox::Types::InverseMatchUnion(
                                             'fieldName'     => 'inverse_union',
-                                            'printableName' => __('Inverse Match Union'),
+                                            'printableName' => 'Inverse Match Union',
                                             'class'         => 'tcenter',
                                             'size'          => 10,
                                             'editable'      => 1,
@@ -260,29 +260,29 @@ sub _table
                                             [
                                              new EBox::Types::Text(
                                                                    'fieldName' => 'inverse_foo',
-                                                                   'printableName' => __('Inverse Foo'),
+                                                                   'printableName' => 'Inverse Foo',
                                                                    'editable'      => 1,
                                                                   ),
                                              new EBox::Types::PortRange(
                                                                         'fieldName' => 'inverse_bar',
-                                                                        'printableName' => __('Inverse Bar'),
+                                                                        'printableName' => 'Inverse Bar',
                                                                         'editable'      => 1,
                                                                        ),
                                              new EBox::Types::IPAddr(
                                                                      'fieldName' => 'inverse_baz',
-                                                                     'printableName' => __('Inverse Baz'),
+                                                                     'printableName' => 'Inverse Baz',
                                                                      'editable' => 1,
                                                                     ),
                                              new EBox::Types::Union::Text(
                                                                           'fieldName' => 'inverse_others',
-                                                                          'printableName' => __('Inverse Other option'),
+                                                                          'printableName' => 'Inverse Other option',
                                                                           'editable' => 1,
                                                                          ),
                                             ]
                                            ),
          new EBox::Types::HasMany(
                                   'fieldName'     => 'member',
-                                  'printableName' => __('Members'),
+                                  'printableName' => 'Members',
                                   'foreignModel'  => 'MemberTable',
                                   'view'          => '/ebox/Objects/View/MemberTable',
                                   'backView'      => '/ebox/Test/View/TestTable',
@@ -290,7 +290,7 @@ sub _table
                                  ),
          new EBox::Types::Service(
                                   'fieldName'     => 'compulsory_service',
-                                  'printableName' => __('Compulsory Service'),
+                                  'printableName' => 'Compulsory Service',
                                   'class'         => 'tcenter',
                                   'editable'      => 1,
                                  ),
@@ -299,16 +299,16 @@ sub _table
     my $dataTable =
         {
             'tableName' => 'TestTable',
-            'printableTableName' => __('Test model'),
+            'printableTableName' => 'Test model',
 	    'defaultController' => '/ebox/Test/Controller/TestTable',
             'defaultActions' => [ 'add', 'del', 'editField', 'changeView' ],
             'tableDescription' => \@tableHead,
             'modelDomain' => 'Logs',
             'class' => 'dataTable',
             'order' => 0,
-            'help' => __('Test model to test types'),
+            'help' => 'Test model to test types',
             'rowUnique' => 0,
-            'printableRowName' => __('row'),
+            'printableRowName' => 'row',
         };
 
     return $dataTable;
@@ -346,9 +346,9 @@ sub compulsoryOptionsCallback
   {
 
       return [
-              { value => 'a', printableValue => __('A') },
-              { value => 'b', printableValue => __('B') },
-              { value => 'c', printableValue => __('C') },
+              { value => 'a', printableValue => 'A' },
+              { value => 'b', printableValue => 'B' },
+              { value => 'c', printableValue => 'C' },
              ];
 
   }
