@@ -14,9 +14,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 # TODO 
-# 	Document this class
-#	Fix the method naming, some names such as
-#	setMemValue and memValue are so broken!!!
+#       Document this class
+#       Fix the method naming, some names such as
+#       setMemValue and memValue are so broken!!!
 #
 
 # Class: EBox::Types::Abstract
@@ -30,46 +30,85 @@ use strict;
 use warnings;
 
 use EBox;
+use Perl6::Junction qw(none);
+use Clone;
+
 
 # Group: Public methods
 
 sub new
 {
-        my $class = shift;
-	my %opts = @_;
-	my $self = {@_};
+    my $class = shift;
+    my %opts = @_;
+    my $self = {@_};
+    
+    if (not $self->{fieldName}) {
+        throw EBox::Exceptions::MissingArgument('fieldName');
+    }
+    
+    if (not $self->{printableName}) {
+        $self->{printableName} = $self->{fieldName};
+    }
 
-	if (defined($self->{'hidden'}) and $self->{'hidden'}) {
-		$self->{'HTMLViewer'} = undef;
-		$self->{'HTMLSetter'} = undef;
-	}
-        bless($self, $class);
 
-        if ( defined ( $self->{'defaultValue'} )) {
-            if ( $self->optional() ) {
-                EBox::warn('Defined default value to an optional field ' .
-                           $self->fieldName());
-            }
-            $self->_setValue($self->{'defaultValue'});
+    if (defined($self->{'hidden'}) and $self->{'hidden'}) {
+        $self->{'HTMLViewer'} = undef;
+        $self->{'HTMLSetter'} = undef;
+    }
+    bless($self, $class);
+    
+    if ( defined ( $self->{'defaultValue'} )) {
+        if ( $self->optional() ) {
+            throw EBox::Exceptions::Internal(
+             'Defined default value to an optional field ' . $self->fieldName()
+                                            );
         }
+        $self->_setValue($self->{'defaultValue'});
+    }
 
-        return $self;
+    return $self;
 }
 
+# Method: clone
+#
+#     Clone the current type safely
+#
+# Returns:
+#
+#     <EBox::Types::Abstract> - the cloned object
+#
+sub clone
+{
+    my ($self) = @_;
+
+    my $clonedType = {};
+    bless($clonedType, ref($self));
+
+    my @suspectedAttrs = qw(model row);
+    foreach my $key (keys %{$self}) {
+        if ( $key eq none(@suspectedAttrs) ) {
+            $clonedType->{$key} = Clone::clone($self->{$key});
+        }
+    }
+    # Just copy the reference
+    foreach my $suspectedAttr (@suspectedAttrs) {
+        if ( exists $self->{$suspectedAttr} ) {
+            $clonedType->{$suspectedAttr} = $self->{$suspectedAttr};
+        }
+    }
+    return $clonedType;
+}
 
 sub type
 {
-	my ($self) = @_;
-
-	return $self->{'type'};
-
+    my ($self) = @_;
+    return $self->{'type'};
 }
 
 sub class
 {
-	my ($self) = @_;
-
-	return $self->{'class'};
+    my ($self) = @_;
+    return $self->{'class'};
 }
 
 # Method: volatile
@@ -85,19 +124,17 @@ sub class
 #     boolean - whether the type is volatile or not
 #
 sub volatile
-  {
+{
+    my ($self) = @_;
 
-      my ($self) = @_;
-
-      return $self->{volatile};
-
-  }
+    return $self->{volatile};
+}
 
 sub unique
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return $self->{'unique'};
+    return $self->{'unique'};
 }
 
 # Method: editable
@@ -111,70 +148,69 @@ sub unique
 #
 sub editable
 {
-	my ($self) = @_;
-
-        if ( $self->volatile() ) {
-            return 0;
-        } else {
-            return $self->{'editable'};
-        }
+    my ($self) = @_;
 
+    if ( $self->volatile() ) {
+        return 0;
+    } else {
+        return $self->{'editable'};
+    }
 }
 
 sub fieldName
 {
-	my ($self) = @_;
-
-	return $self->{'fieldName'};
+    my ($self) = @_;
+    
+    return $self->{'fieldName'};
 }
 
 sub fields
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return ($self->fieldName());
+    return ($self->fieldName());
 }
 
 sub printableName
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return $self->{'printableName'};
+    return $self->{'printableName'};
 }
 
 sub printableValue
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return $self->filter();
+    return $self->filter();
 }
 
 # Method: filter
 #
-# 	This method is used to filter the output of printableValue
+#       This method is used to filter the output of printableValue
 #
 # Returns:
-#	
-#	Output filtered
+#       
+#       Output filtered
 sub filter
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	my $filterFunc = $self->{'filter'};
-	if ($filterFunc) {
-		return (&$filterFunc($self));
-	} else {
-		return $self->{'value'};
-	}
+    my $filterFunc = $self->{'filter'};
+    if ($filterFunc) {
+        return (&$filterFunc($self));
+    } else {
+        return $self->{'value'};
+    }
 
 }
 
 
 sub value
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return $self->{'value'};
+    return $self->{'value'};
 }
 
 # Method: defaultValue
@@ -186,42 +222,60 @@ sub value
 #     The default value
 #
 sub defaultValue
-  {
+{
+    my ($self) = @_;
 
-      my ($self) = @_;
+    return $self->{'defaultValue'};
 
-      return $self->{'defaultValue'};
+}
+
+# Method: help
+#
+#   Method to retrieve the associated help to this type
+#
+# Returns:
+#
+#     string
+#
+sub help 
+{
+    my ($self) = @_;
+    
+    if (defined($self->{help})) {
+        return $self->{help};
+    } else {
+        return '';
+    }
+
+}
 
-  }
 
 sub trailingText
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return $self->{'trailingText'};
+    return $self->{'trailingText'};
 }
 
 sub leadingText
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return $self->{'leadingText'};
+    return $self->{'leadingText'};
 }
 
 sub setOptional # (optional)
-  {
-
+{
     my ($self, $optional) = @_;
 
     $self->{'optional'} = $optional;
-
-  }
+}
 
 sub optional
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return $self->{'optional'};
+    return $self->{'optional'};
 }
 
 # Method: disabled
@@ -238,7 +292,6 @@ sub disabled
     my ($self) = @_;
 
     return $self->{'disabled'};
-
 }
 
 # Method: allowUnsafeChars
@@ -258,7 +311,6 @@ sub allowUnsafeChars
     my ($self) = @_;
 
     return $self->{'allowUnsafeChars'};
-
 }
 
 # Method: paramExist
@@ -284,25 +336,22 @@ sub paramExist
 #      from
 #
 sub storeInGConf
-  {
-      my ($self, @params) = @_;
-
-      if ( $self->volatile() ) {
-          if ( $self->storer() ) {
+{
+    my ($self, @params) = @_;
+    
+    if ( $self->volatile() ) {
+        if ( $self->storer() ) {
               my $storerProc = $self->storer();
               &$storerProc($self);
           }
-      } else {
-          $self->_storeInGConf(@params);
-      }
-
-  }
-
-sub restoreFromGconf
-{
-
+    } else {
+        $self->_storeInGConf(@params);
+    }
+    
 }
 
+
+
 # Method: setValue
 #
 #      Set the value for the type. Its behaviour is equal to
@@ -322,13 +371,11 @@ sub restoreFromGconf
 #      value - the value to set
 #
 sub setValue
-  {
+{
+    my ($self, $value) = @_;
 
-      my ($self, $value) = @_;
-
-      $self->_setValue($value);
-
-  }
+    $self->_setValue($value);
+}
 
 # Method: setMemValue
 #
@@ -411,7 +458,7 @@ sub cmp
 #      Restore the value from a hash.
 #
 #      If the type is volatile, the memory value will be set from the
-#      <EBox::Types::Abstract::wangler>. If the function is empty, a
+#      <EBox::Types::Abstract::acquirer>. If the function is empty, a
 #      function which returns '' will be used.
 #
 # Parameters:
@@ -420,19 +467,18 @@ sub cmp
 #
 #
 sub restoreFromHash
-  {
-
-      my ($self, $hashRef) = @_;
-
-      if ( $self->volatile() ) {
-          my $volatileFunc = $self->{acquirer};
+{
+    my ($self, $hashRef) = @_;
+    
+    if ( $self->volatile() ) {
+        my $volatileFunc = $self->{acquirer};
           $volatileFunc = \&_identity unless defined ( $volatileFunc );
-          $self->{value} = &$volatileFunc($self);
-      } else {
-          $self->_restoreFromHash($hashRef);
-      }
+        $self->{value} = &$volatileFunc($self);
+    } else {
+        $self->_restoreFromHash($hashRef);
+    }
 
-  }
+}
 
 # Method: acquirer
 #
@@ -451,13 +497,12 @@ sub restoreFromHash
 #      function - the pointer to that function
 #
 sub acquirer
-  {
+{
+    my ($self) = @_;
 
-      my ($self) = @_;
-
-      return $self->{acquirer};
-
-  }
+    return $self->{acquirer};
+    
+}
 
 # Method: storer
 #
@@ -472,17 +517,22 @@ sub acquirer
 #      function - the pointer to that function
 #
 sub storer
-  {
-
-      my ($self) = @_;
-
-      return $self->{storer};
-
-  }
-
-sub isEqualTo
 {
+    my ($self) = @_;
 
+    return $self->{storer};
+}
+
+# Method: isEqualTo
+#
+#  returns if a type object is equal to another
+#  default implementation uses the cmp method
+#  soon to be deprecated. 
+
+sub isEqualTo 
+{
+    my ($self, $other) = @_;
+    return $self->cmp($other) == 0;
 }
 
 # Method: row
@@ -494,8 +544,8 @@ sub isEqualTo
 #   row - hash ref containting a row
 sub row
 {
-	my ($self) =  @_;
-	return $self->{'row'};
+    my ($self) =  @_;
+    return $self->{'row'};
 }
 
 # Method: setRow
@@ -509,8 +559,8 @@ sub row
 #   row - hash ref of a row
 sub setRow
 {
-	my ($self, $row) = @_;
-	$self->{'row'} = $row;
+    my ($self, $row) = @_;
+    $self->{'row'} = $row;
 }
 
 # Method: setModel
@@ -524,8 +574,8 @@ sub setRow
 #   model -  an object of type <EBox::Model::DataTable>
 sub setModel
 {
-	my ($self, $id) = @_;
-	$self->{'model'} = $id;
+    my ($self, $id) = @_;
+    $self->{'model'} = $id;
 }
 
 # Method: model
@@ -537,8 +587,8 @@ sub setModel
 #   model -  an object of type <EBox::Model::DataTable>
 sub model
 {
-	my ($self) =  @_;
-	return $self->{'model'};
+    my ($self) =  @_;
+    return $self->{'model'};
 }
 
 sub HTMLSetter
@@ -571,9 +621,9 @@ sub HTMLViewer
 #       params - hash ref with the fields to fill the type with its
 #       appropiate values
 sub _setMemValue
-  {
+{
 
-  }
+}
 
 # Method: _storeInGConf
 #
@@ -592,9 +642,9 @@ sub _setMemValue
 #      from
 #
 sub _storeInGConf
-  {
+{
 
-  }
+}
 
 
 # Method: _restoreFromHash
@@ -609,9 +659,9 @@ sub _storeInGConf
 #      the value from this type
 #
 sub _restoreFromHash
-  {
+{
 
-  }
+}
 
 # Method: _paramIsValid
 #
@@ -632,9 +682,9 @@ sub _restoreFromHash
 #      does not contain a valid data for this type
 #
 sub _paramIsValid
-  {
+{
 
-  }
+}
 
 # Method: _paramIsSet
 #
@@ -653,11 +703,9 @@ sub _paramIsValid
 #      data to fill the type
 #
 sub _paramIsSet
-  {
-
+{
       return 0;
-
-  }
+}
 
 # Method: _setValue
 #
@@ -669,11 +717,9 @@ sub _paramIsSet
 #     values - the value to set
 #
 sub _setValue # (value)
-  {
-
-      return;
-
-  }
+{
+    return;
+}
 
 # Group: Private functions
 
@@ -686,10 +732,8 @@ sub _setValue # (value)
 #      instancedType - <EBox::Types::Abstract>
 #
 sub _identity
-  {
-
+{
       return '';
-
-  }
+}
 
 1;
