@@ -14,21 +14,20 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 package EBox::Types::IPAddr;
+use base 'EBox::Types::Abstract';
 
 use EBox::Validate qw(:all);
 use EBox::Gettext;
 use EBox::Exceptions::MissingArgument;
+use Net::IP;
 
 use strict;
 use warnings;
 
-use base 'EBox::Types::Abstract';
-
-
 sub new
 {
         my $class = shift;
-    	my %opts = @_;
+        my %opts = @_;
 
         unless (exists $opts{'HTMLSetter'}) {
             $opts{'HTMLSetter'} ='/ajax/setter/ipaddrSetter.mas';
@@ -36,7 +35,7 @@ sub new
         unless (exists $opts{'HTMLViewer'}) {
             $opts{'HTMLViewer'} ='/ajax/viewer/textViewer.mas';
         }
-	
+        
         $opts{'type'} = 'ipaddr';
         my $self = $class->SUPER::new(%opts);
 
@@ -50,9 +49,9 @@ sub paramExist
 {
         my ($self, $params) = @_;
 
-	my $ip =  $self->fieldName() . '_ip';
- 	my $mask =  $self->fieldName() . '_mask';
-	
+        my $ip =  $self->fieldName() . '_ip';
+        my $mask =  $self->fieldName() . '_mask';
+        
         return (defined($params->{$ip}) and defined($params->{$mask}));
 
 }
@@ -60,71 +59,14 @@ sub paramExist
 
 sub printableValue
 {
-	my ($self) = @_;
+        my ($self) = @_;
 
-	if (defined($self->{'ip'}) and defined($self->{'mask'})) {
-		return "$self->{'ip'}/$self->{'mask'}";
-	} else   {
-		return "";
-	}
-	
-}
-
-sub size
-{
-	my ($self) = @_;
-
-	return $self->{'size'};
-}
-
-sub compareToHash
-{
-	my ($self, $hash) = @_;
-
-	my ($oldIp, $oldMask) = $self->_ipNetmask();
-	my $ip = $self->fieldName() . '_ip';
- 	my $mask = $self->fieldName() . '_mask';
-	
-	if ($oldIp ne $hash->{$ip}) {
-		return 0;
-	}
-
-	if ($oldMask ne $hash->{$mask}) {
-		return 0;
-	}
-
-	return 1;
-}
-
-sub isEqualTo
-{
-	my ($self, $newObject) = @_;
-
-	return ($self->printableValue() eq $newObject->printableValue());
-}
-
-sub fields
-{
-	my ($self) = @_;
-	
-	my $ip = $self->fieldName() . '_ip';
- 	my $mask = $self->fieldName() . '_mask';
-	
-	return ($ip, $mask);
-}
-
-sub ip
-{
-	my ($self) = @_;
-
-	return $self->{'ip'};
-}
-
-sub mask 
-{
-	my ($self) = @_;
-
-	return $self->{'mask'};
+        if (defined($self->{'ip'}) and defined($self->{'mask'})) {
+                return "$self->{'ip'}/$self->{'mask'}";
+        } else   {
+                return "";
+        }
+        
 }
 
 # Method: cmp
@@ -137,16 +79,15 @@ sub cmp
 {
     my ($self, $compareType) = @_;
 
-    unless ( $self->type() eq $compareType->type() ) {
+    unless ( (ref $self) eq (ref $compareType) ) {
         return undef;
     }
-
     my $ipA = new Net::IP($self->printableValue());
     my $ipB = new Net::IP($compareType->printableValue());
 
     if ( $ipA->bincomp('lt', $ipB) ) {
         return -1;
-    } elsif ( $ipB->bincomp('eq', $ipB)) {
+    } elsif ( $self->printableValue() eq $compareType->printableValue() ) {
         return 0;
     } else {
         return 1;
@@ -154,6 +95,57 @@ sub cmp
 
 }
 
+sub size
+{
+        my ($self) = @_;
+
+        return $self->{'size'};
+}
+
+sub compareToHash
+{
+        my ($self, $hash) = @_;
+
+        my ($oldIp, $oldMask) = $self->_ipNetmask();
+        my $ip = $self->fieldName() . '_ip';
+        my $mask = $self->fieldName() . '_mask';
+        
+        if ($oldIp ne $hash->{$ip}) {
+                return 0;
+        }
+
+        if ($oldMask ne $hash->{$mask}) {
+                return 0;
+        }
+
+        return 1;
+}
+
+
+sub fields
+{
+        my ($self) = @_;
+        
+        my $ip = $self->fieldName() . '_ip';
+        my $mask = $self->fieldName() . '_mask';
+        
+        return ($ip, $mask);
+}
+
+sub ip
+{
+        my ($self) = @_;
+
+        return $self->{'ip'};
+}
+
+sub mask 
+{
+        my ($self) = @_;
+
+        return $self->{'mask'};
+}
+
 # Group: Protected methods
 
 # Method: _setMemValue
@@ -164,13 +156,13 @@ sub cmp
 #
 sub _setMemValue
 {
-	my ($self, $params) = @_;
+        my ($self, $params) = @_;
 
-	my $ip =  $self->fieldName() . '_ip';
- 	my $mask =  $self->fieldName() . '_mask';
+        my $ip =  $self->fieldName() . '_ip';
+        my $mask =  $self->fieldName() . '_mask';
 
-	$self->{'ip'} = $params->{$ip};
-	$self->{'mask'} = $params->{$mask};
+        $self->{'ip'} = $params->{$ip};
+        $self->{'mask'} = $params->{$mask};
 
 }
 
@@ -184,16 +176,16 @@ sub _storeInGConf
 {
         my ($self, $gconfmod, $key) = @_;
 
- 	my $ipKey = "$key/" . $self->fieldName() . '_ip';
- 	my $maskKey = "$key/" . $self->fieldName() . '_mask';
+        my $ipKey = "$key/" . $self->fieldName() . '_ip';
+        my $maskKey = "$key/" . $self->fieldName() . '_mask';
 
-	if ($self->{'ip'}) {
-        	$gconfmod->set_string($ipKey, $self->{'ip'});
-        	$gconfmod->set_string($maskKey, $self->{'mask'});
-	} else {
-		$gconfmod->unset($ipKey);
-		$gconfmod->unset($maskKey);
-	}
+        if ($self->{'ip'}) {
+                $gconfmod->set_string($ipKey, $self->{'ip'});
+                $gconfmod->set_string($maskKey, $self->{'mask'});
+        } else {
+                $gconfmod->unset($ipKey);
+                $gconfmod->unset($maskKey);
+        }
 }
 
 # Method: _restoreFromHash
@@ -204,13 +196,13 @@ sub _storeInGConf
 #
 sub _restoreFromHash
 {
-	my ($self, $hash) = @_;
+        my ($self, $hash) = @_;
 
- 	my $ip = $self->fieldName() . '_ip';
- 	my $mask = $self->fieldName() . '_mask';
+        my $ip = $self->fieldName() . '_ip';
+        my $mask = $self->fieldName() . '_mask';
 
-	$self->{'ip'} = $hash->{$ip};
-	$self->{'mask'} = $hash->{$mask};
+        $self->{'ip'} = $hash->{$ip};
+        $self->{'mask'} = $hash->{$mask};
 }
 
 
@@ -294,9 +286,9 @@ sub _setValue # (value)
 # Helper funcionts
 sub _ipNetmask
 {
-	my ($self) = @_;
+        my ($self) = @_;
 
-	return ($self->{'ip'}, $self->{'mask'});
+        return ($self->{'ip'}, $self->{'mask'});
 
 }
 
